@@ -10,6 +10,17 @@ import time
 from suds.client import Client
 from suds import WebFault
 
+WSDLS = {
+        '2': 'https://ws2.responsys.net/webservices/wsdl/ResponsysWS_Level1.wsdl',
+        '5': 'https://ws5.responsys.net/webservices/wsdl/ResponsysWS_Level1.wsdl',
+        'rtm4': 'https://rtm4.responsys.net/tmws/services/TriggeredMessageWS?wsdl',
+}
+
+ENDPOINTS = {
+        '2': 'https://ws2.responsys.net/webservices/services/ResponsysWSService',
+        '5': 'https://ws5.responsys.net/webservices/services/ResponsysWSService',
+        'rtm4': 'http://rtm4.responsys.net:80/tmws/services/TriggeredMessageWS',
+}
 
 def retry(func):
     ''' Only use this wrapper on methods of Interact '''
@@ -23,7 +34,7 @@ def retry(func):
         self = args[0]
         # Let's be a little generous here. Makes my life in web support
         # a bit easier.
-        timeouts = [10, 20, 30, 60, 60, 60, 60]
+        timeouts = [15, 30, 60]
         while True:
             try:
                 return func(*args, **kwargs)
@@ -77,7 +88,7 @@ class Interact(object):
 
     def config_creds(self, username, password, pod, config_path=None):
         self.pod = str(pod)
-        assert self.pod in {'2', '5'}, 'Pod should be 2 or 5'
+        assert self.pod in {'2', '5', 'rtm4'}, 'Pod should be 2 or 5'
         if (
             username is None and 
             password is None and 
@@ -114,10 +125,8 @@ class Interact(object):
         decrypt with the private key with something like wireshark.
         '''
         self.config_creds(username, password, pod, config_path=config_path)
-        wsdl_url  = 'https://ws' + self.pod + \
-            '.responsys.net/webservices/wsdl/ResponsysWS_Level1.wsdl'
-        endpoint = 'https://ws' + self.pod + \
-            '.responsys.net/webservices/services/ResponsysWSService'
+        wsdl_url = WSDLS[self.pod]
+        endpoint = ENDPOINTS[self.pod]
         self.client = self._create_client(wsdl_url, endpoint, proxy=proxy)
         self.client.set_options(timeout=timeout)
         loginResponse = self.client.service.login(self.username,
@@ -300,6 +309,32 @@ class Interact(object):
             trig_data,
         )
 
+    def rtm_trigger(self, campaign, email, data={}, email_format='HTML'):
+        ''' call sendTriggeredMessages to one recipient '''
+        create = self.client.factory.create
+        rdata = create('RecipientData')
+        rdata.emailAddress = email
+        rdata.emailFormat = email_format
+        rdata.personalizationData = []
+        for k,v in data.items():
+            pd = create('PersonalizationData')
+            pd.name = k
+            pd.value = v
+            rdata.personalizationData += [pd]
+        if not rdata.personalizationData:
+            pd = create('PersonalizationData')
+            pd.name = ''
+            pd.value = ''
+            rdata.personalizationData += [pd]
+        return self.client.service.sendTriggeredMessages(
+            campaign,
+            [rdata],
+        )
+
+    def rtm_check(self, ids):
+        return self.client.service.checkTriggeredMessages(
+            ids
+        )
 
     def _create_recipient_data(self, recipients, list_obj):
         ''' Creates SOAP objects out of recipient dicts and their list.
